@@ -164,7 +164,7 @@ class Sf:
         self.sfMeta = sfMeta
         # Alternative way to authenticate using SFDC Metadata API
         # sfMeta = SfdcSession(username=sfUsername,password=sfPassword,token='',is_sandbox=isSandbox)
-        sfMeta._api_version = "51.0"
+        sfMeta._api_version = "54.0"
         tooling = SfdcToolingApi(sfMeta)
         self.tooling = tooling
         
@@ -804,7 +804,7 @@ class Sf:
         profile_metadata = pd.DataFrame(zeep.helpers.serialize_object(self.metadata_list("Profile")))
         profile_metadata = profile_metadata[['id', 'fullName']].copy()
         profile_metadata
-        user_profile_id = transform_sf_result_set_rec(self.sf.query(f"Select Id, ProfileId FROM User WHERE Username = '{username}'")['records'])
+        user_profile_id = transform_sf_result_set_rec(self.sf.query_all(f"Select Id, ProfileId FROM User WHERE Username = '{username}'")['records'])
         user_profile = profile_metadata[profile_metadata['id'] == user_profile_id['User.ProfileId'].values[0]]['fullName'].values[0]
 
         async_profile_read = async_wrap(self.metadata_read)
@@ -1107,7 +1107,7 @@ class Sf:
     def field_permission_user_check(self, object, permission, users=[]):
         # Similar to the field_permission_check function, but this one will return a list of users that have the specified permission on the specified object
         
-        relevant_ps_and_profiles = transform_sf_result_set_rec(self.sf.query(f"""
+        relevant_ps_and_profiles = transform_sf_result_set_rec(self.sf.query_all(f"""
                                                 SELECT ParentId,
                                                         Field,
                                                         PermissionsEdit,
@@ -1125,7 +1125,7 @@ class Sf:
 
         relevant_ps_and_profiles_list = "','".join(relevant_ps_and_profiles['FieldPermissions.ParentId'].unique().tolist())
 
-        data = transform_sf_result_set_rec(self.sf.query(f"""SELECT Assignee.Id, Assignee.Name,Assignee.IsActive, 
+        data = transform_sf_result_set_rec(self.sf.query_all(f"""SELECT Assignee.Id, Assignee.Name,Assignee.IsActive, 
                                                                 Assignee.UserName, PermissionSet.Id, 
                                                                 PermissionSet.isOwnedByProfile, PermissionSet.Profile.Name, PermissionSet.Label
                                                                 FROM PermissionSetAssignment
@@ -1153,11 +1153,11 @@ class Sf:
                                                 )
                         for user in permission_set_violations['User.Username'].unique():
                                 result.append({"UserName": user, 
-                                                                                "Object API Name" : object,
-                                                                                "Field API Name" : field,
-                                                                                "Permission": permission,
-                                                                                "Profile": "",
-                                                                                "Permission Set": "; ".join(list(permission_set_violations[permission_set_violations['User.Username'] == user]['PermissionSet.Label'].unique()))})
+                                                "Object API Name" : object,
+                                                "Field API Name" : field,
+                                                "Permission": permission,
+                                                "Profile": "",
+                                                "Permission Set": "; ".join(list(permission_set_violations[permission_set_violations['User.Username'] == user]['PermissionSet.Label'].unique()))})
                 return result
         else:
                 return []
@@ -1250,8 +1250,19 @@ class Sf:
         getattr(self.sf.mdapi, metadata_type).create(mdapi_object)
         return mdapi_object
 
-    def metadata_list(self, metadata_type: str) -> list:
-        query = self.sf.mdapi.ListMetadataQuery(type=metadata_type)
+    def metadata_list(self, metadata_type: str = '', metadata_type_list: list[str] = []) -> list:
+        if len(metadata_type_list) == 0 and metadata_type == '':
+            query = self.sf.mdapi.ListMetadataQuery(type=metadata_type)
+        elif len(metadata_type_list) > 3:
+            raise Exception("You can only query up to 3 metadata types at a time")
+        
+        elif len(metadata_type_list) > 0:
+            query = []
+            for metadata_type in metadata_type_list:
+                query.append(self.sf.mdapi.ListMetadataQuery(type=metadata_type))
+        else:
+            raise Exception("Please populate either metadata_type or metadata_type_list, but not both.")
+        
         query_response = self.sf.mdapi.list_metadata(query)
         return query_response
     
